@@ -7,6 +7,7 @@ use warnings;
 
 
 use Data::Dumper;
+use WWW::Webrobot::Util qw/ascii/;
 
 
 sub new {
@@ -15,9 +16,9 @@ sub new {
     my $self = bless({}, ref($class) || $class);
     my %parm = (@_);
 
-    $self -> {summary} = defined $parm{summary} ? $parm{summary} : 0;
-    $self -> {format} = defined $parm{format} ? $parm{format} : 1;
-    $self -> {failed} = [];
+    $self->{summary} = defined $parm{summary} ? $parm{summary} : 0;
+    $self->{format} = defined $parm{format} ? $parm{format} : 1;
+    $self->{failed} = [];
     bless ($self, $class);
     return $self;
 }
@@ -32,7 +33,7 @@ sub item_pre {
     my $url = $arg->{url};
     my $url_out = ref($url) ? Dumper($url) : ($url || "");
     my $points = $arg->{is_recursive} ? "... " : "";
-    ($self -> {format} > 0) && print "$points$arg->{method} $url_out\n";
+    print ascii("$points$arg->{method} $url_out"), "\n" if $self->{format} > 0;
 }
 
 
@@ -45,49 +46,51 @@ sub failstr {
     };
 }
 
-my $short = failstr(["ok     ", "fail   ", "invalid"], "<no assertion>");
-my $long = failstr(["Ok", "FAILED", "INVALID"], "<no assertion>");
+my $short = failstr(["ok     ", "fail   ", "invalid"], "[no assertion]");
+my $long = failstr(["Ok", "FAILED", "INVALID"], "[no assertion]");
 
 sub item_post {
     my ($self, $r, $arg) = @_;
     my $last_errcode = "  -";
-    foreach ($self -> stack_responses($r)) {
-	print $self->response2string($_), "\n" if $self->{format} > 0;
-	$last_errcode = $_->{_rc};
+    foreach ($self -> _stack_responses($r)) {
+        print $self->_response2string($_), "\n" if $self->{format} > 0;
+        $last_errcode = $_->{_rc};
     }
     if ($self -> {format} > 0) {
-	print " "x8, $long->($arg->{fail}), ": ",
-	$arg->{description} || "No description", "\n";
+        print " "x8, $long->($arg->{fail}), ": ",
+            ascii($arg->{description}) || "No description", "\n";
     }
     else {
         print $short->($arg->{fail}), " $last_errcode ",
-        $arg->{method}, " ", $arg->{url}, "\n";
+            $arg->{method}, " ", $arg->{url}, "\n";
     }
     if ($arg->{new_properties}) {
-        print " "x8 . "Property '$_->[0]' => '$_->[1]'\n" foreach (@{$arg->{new_properties}});
+        foreach (@{$arg->{new_properties}}) {
+            print " "x8 . ascii("Property '$_->[0]' => '$_->[1]'") . "\n"
+        }
     }
-    push @{$self -> {failed}}, $arg if $arg->{fail};
+    push @{$self->{failed}}, $arg if $arg->{fail};
 }
 
 
 sub global_end {
     my $self = shift;
     if ($self -> {summary}) {
-	if (scalar @{$self -> {failed}} == 0) {
-	    print "Es sind keine Fehler aufgetreten.\n";
-	}
-	else {
-	    print "\n", "Fehlerliste:\n", "------------\n";
-	    foreach my $arg (@{$self -> {failed}}) {
-		print $short->($arg->{fail}), ": ", $arg->{method}, " ", $arg->{url}, "\n";
-	    }
-	}
+        if (scalar @{$self->{failed}} == 0) {
+            print "No errors.\n";
+        }
+        else {
+            print "\n", "ERRORS:\n", "------------\n";
+            foreach my $arg (@{$self -> {failed}}) {
+                print $short->($arg->{fail}), ": ", $arg->{method}, " ", $arg->{url}, "\n";
+            }
+        }
     }
 }
 
 
 # private
-sub stack_responses {
+sub _stack_responses {
     my ($self, $r) = @_;
     my @seq = ();
     while (defined($r)) {
@@ -98,7 +101,7 @@ sub stack_responses {
 }
 
 # private
-sub response2string {
+sub _response2string {
     my ($self, $r) = @_;
     return "" if !defined($r);
     return " " x 8,
